@@ -6,7 +6,7 @@
 ;; Copyright (C) 2003-2006 Robert Widhopf-Fenk
 ;; Copyright (C) 2024-2025 The VM Developers
 ;;
-;; Version: 8.3.0snapshot
+;; Version: 8.3.3snapshot
 ;; Maintainer: viewmail-info@nongnu.org
 ;; URL: https://gitlab.com/emacs-vm/vm
 ;; Package-Requires: ((emacs "28.1") (vcard "0.2.2"))
@@ -95,11 +95,15 @@
   (error "VM requires Emacs %s or later" vm-min-emacs-version))
 
 
-;; Ensure that vm-autoloads is loaded in case the user is using VM
-;; autoloads 
-
-(if (not (featurep 'xemacs))
-    (require 'vm-autoloads))
+;; emacs 28 doesn't generate a provide in when generating autoloads
+;; yet does bbdb-vm.el  (require 'vm-autoloads). This workds around
+;; this issue, yet allows vm.el to work if evaluated without going through
+;; vm-autoloads.
+(cond ((<= emacs-major-version 28)
+       (progn
+	 (load-library "vm-autoloads")
+	 (provide 'vm-autoloads)))
+      (t (require 'vm-autoloads)))
 
 ;;;###autoload
 (cl-defun vm (&optional folder &key read-only interactive
@@ -1549,30 +1553,6 @@ summary buffer to select a folder."
   (interactive)
   (find-file-other-frame vm-init-file))
 
-(defun vm-check-emacs-version ()
-  "Checks the version of Emacs and gives an error if it is unsupported."
-  (cond ((and (featurep 'xemacs) (< emacs-major-version 21))
-	 (error "VM %s must be run on XEmacs 21 or a later version."
-		(vm-version)))
-	((and (not (featurep 'xemacs)) (< emacs-major-version 21))
-	 (error "VM %s must be run on GNU Emacs 21 or a later version."
-		(vm-version)))))
-
-;; This function is now defunct.  USR, 2011-11-12
-
-;; (defun vm-set-debug-flags ()
-;;   (or stack-trace-on-error
-;;       debug-on-error
-;;       (setq stack-trace-on-error
-;; 	    '(
-;; 	      wrong-type-argument
-;; 	      wrong-number-of-arguments
-;; 	      args-out-of-range
-;; 	      void-function
-;; 	      void-variable
-;; 	      invalid-function
-;; 	     ))))
-
 (defun vm-toggle-thread-operations ()
   "Toggle the variable `vm-enable-thread-operations'.
 
@@ -1614,11 +1594,9 @@ attributes, adding/deleting labels etc."
   "If this is the first time VM has been run in this Emacs session,
 do some necessary preparations.  Otherwise, update the count of
 draft messages."
-  ;;  (vm-set-debug-flags)
   (if (or (not (boundp 'vm-session-beginning))
 	  vm-session-beginning)
       (progn
-        (vm-check-emacs-version)
         (require 'vm-macro)
         (require 'vm-vars)
         (require 'vm-misc)
